@@ -93,6 +93,35 @@ trim(char *str)
   return str;
 } 
 
+int
+valid(const char *s)
+{
+ int flag=0;
+ int i = 0;
+
+ for(i = 0; i <= 255; i++){
+    flag = flag || s[i]=='\0';
+ }
+
+  if(flag){
+    return 1;
+  } else {
+    return 0;
+  }
+}
+
+int 
+empty(const char *s)
+{
+  if(!s) return 1;
+  if(strlen(s) < 1) return 1;
+
+  while ((ISSPACE(*s)))
+     s++;
+  return (*s == '\0');
+}
+
+
 int
 word_count(char pattern, char *s)
 {
