@@ -214,7 +214,11 @@ http_request(CONN *C, URL *U, CLIENT *client)
   C->connection.reuse     = (C->connection.max==1)?0:my.keepalive;
   C->connection.tested    = (C->connection.tested==0)?1:C->connection.tested; 
   C->auth.www             = client->auth.www;
+  C->auth.wwwchlg         = client->auth.wwwchlg;
+  C->auth.wwwcred         = client->auth.wwwcred;
   C->auth.proxy           = client->auth.proxy;
+  C->auth.proxychlg       = client->auth.proxychlg;
+  C->auth.proxycred       = client->auth.proxycred;
   C->auth.type.www        = client->auth.type.www;
   C->auth.type.proxy      = client->auth.type.proxy;
   memset(C->buffer, 0, sizeof(C->buffer));
@@ -248,8 +252,13 @@ http_request(CONN *C, URL *U, CLIENT *client)
   ); 
 
   if(!C->connection.reuse || C->connection.status == 0){
-    debug("client.c:%d new_socket: %s:%d", __LINE__, U->hostname, U->port); 
-    C->sock = new_socket(C, U->hostname, U->port);
+    if(my.proxy.required){
+      debug("client.c:%d new_socket: %s:%d", __LINE__, my.proxy.hostname, my.proxy.port); 
+      C->sock = new_socket(C, my.proxy.hostname, my.proxy.port);
+    } else {
+      debug("client.c:%d new_socket: %s:%d", __LINE__, U->hostname, U->port); 
+      C->sock = new_socket(C, U->hostname, U->port);
+    }
   }
 
   if(my.keepalive){
@@ -296,11 +305,6 @@ http_request(CONN *C, URL *U, CLIENT *client)
   /**
    * read from socket and collect statistics.
    */
-/*
-  head     =  http_read_headers(C, U->hostname); 
-  if(!head){  C->connection.reuse = 0; socket_close(C); return FALSE; } 
-*/
-
   if((head = http_read_headers(C, U))==NULL){
     C->connection.reuse = 0; 
     socket_close(C); 
@@ -313,7 +317,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
   if(!my.zero_ok && (bytes < 1)){ 
     C->connection.reuse = 0; 
     socket_close(C); 
-    xfree(head); 
+    http_free_headers(head); 
     debug("zero bytes %s:%d", __FILE__, __LINE__);
     return FALSE; 
   } 
@@ -394,7 +398,7 @@ http_request(CONN *C, URL *U, CLIENT *client)
           memcpy(redirect_url, U, sizeof(URL));
           redirect_url->pathname = head->redirect;
         } else {
-          redirect_url = add_redirect(head->redirect, U->port, U->urlid);
+          redirect_url = add_url(head->redirect, U->urlid);
         }
         if((http_request(C, redirect_url, client)) == FALSE)
           return FALSE;
@@ -409,6 +413,10 @@ http_request(CONN *C, URL *U, CLIENT *client)
       if((client->auth.bids.www++) < my.bids - 1){
         if(head->auth.type.www == DIGEST){
           client->auth.type.www = DIGEST;
+	  if(set_digest_authorization(WWW, &(client->auth.wwwchlg), &(client->auth.wwwcred), &(client->rand_r_SEED), head->auth.realm.www, head->auth.challenge.www) < 0) {
+	    fprintf(stderr, "ERROR from set_digest_authorization\n");
+	    return FALSE;
+	  }
           break; 
         }
         if(head->auth.type.www == BASIC){
@@ -429,6 +437,10 @@ http_request(CONN *C, URL *U, CLIENT *client)
       if((client->auth.bids.proxy++) < my.bids - 1){
         if(head->auth.type.proxy == DIGEST){
           client->auth.type.proxy =  DIGEST;
+	  if(set_digest_authorization(PROXY, &(client->auth.proxychlg), &(client->auth.proxycred), &(client->rand_r_SEED), head->auth.realm.proxy, head->auth.challenge.proxy) < 0) {
+	    fprintf(stderr, "ERROR from set_digest_authorization\n");
+	    return FALSE;
+	  } 
           break;
         }
         if(head->auth.type.proxy == BASIC){
@@ -439,13 +451,23 @@ http_request(CONN *C, URL *U, CLIENT *client)
           return FALSE;
       }
       break;
+    case 500:
+    case 501:
+    case 502:
+    case 503: 
+    case 504: 
+    case 505:
+    case 506:
+    case 507:
+    case 508:
+    case 509:
+      return FALSE;
     default:
       break;
   }
 
   client->hits  ++; 
-  xfree(head->redirect);
-  xfree(head); 
+  http_free_headers(head);
 
   return TRUE;
 }
