@@ -1,7 +1,7 @@
 /**
  * Cookies Support
  *
- * Copyright (C) 2000-2007 by
+ * Copyright (C) 2000-2009 by
  * Jeffrey Fulmer - <jeff@joedog.org>, et al. 
  * Copyright (C) 2002 the University of Kansas
  * This file is distributed as part of Siege 
@@ -169,7 +169,7 @@ add_cookie(pthread_t id, char *host, char *cookiestr)
   }
   if(!found){
     fresh = (CNODE*)xmalloc(sizeof(CNODE));
-    if(!fresh) joe_fatal("out of memory!"); 
+    if(!fresh) NOTIFY(FATAL, "out of memory!"); 
     fresh->threadID = id;
     fresh->name     = xstrdup(name);
     fresh->value    = xstrdup(value);
