@@ -1,7 +1,7 @@
 /**
  * Cookie support
  *
- * Copyright (C) 2001-2002 Jeffrey Fulmer <jdfulmer@armstrong.com>
+ * Copyright (C) 2001-2006 Jeffrey Fulmer <jeff@joedog.org>
  * This file is part of Siege
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,14 +27,42 @@
 
 #include <stdlib.h>
 #include <joedog/joedog.h>
+#include <joedog/boolean.h>
 
-#define MAX_COOKIE_SIZE 4096
+#define MAX_COOKIE_SIZE 8192
 
-int  add_cookie( pthread_t id, char *host, char *value );
-int  delete_cookie( pthread_t id, char *name ); 
-int  delete_all_cookies( pthread_t id );
-int  check_cookie( char *domain, char *value );
-char *get_cookie_header(pthread_t id, char *domain, char *cookie);
+/**
+ * cookie node
+ */
+typedef struct CNODE
+{
+  int    index;
+  pthread_t threadID;
+  char   *name;
+  char   *value;
+  char   *path;
+  char   *domain;
+  time_t expires;
+  char   *expirestr;
+  char   *version;
+  char   *max;
+  int    secure;
+  struct CNODE  *next;
+} CNODE;
+
+typedef struct
+{
+  CNODE *first;
+  pthread_mutex_t mutex;
+} COOKIE;
+
+int      add_cookie(pthread_t id, char *host, char *value);
+BOOLEAN  delete_cookie(pthread_t id, char *name); 
+int      delete_all_cookies(pthread_t id);
+int      check_cookie(char *domain, char *value);
+char     *get_cookie_header(pthread_t id, char *domain, char *cookie);
+
+extern COOKIE *cookie;
 
 #endif/*COOKIES_H*/
 
