@@ -31,7 +31,7 @@
 #include <joedog/joedog.h>
 
 char *
-evaluate( HASH hash_table, char *buf )
+evaluate(HASH hash_table, char *buf)
 {
   int  x   = 0;
   int  ENV = 0;
@@ -40,40 +40,42 @@ evaluate( HASH hash_table, char *buf )
   char *ptr;
   char *string;
   
-  char *result = xcalloc(BUFSIZE, sizeof(char));
+  char *result = xrealloc(buf, BUFSIZE * sizeof(char));
+  if(result != NULL)
+    buf = result;
+
+  const char *scan = strchr( buf, '$') + 1;
+  len = (strlen(buf) - strlen(scan)) -1;
  
-  const char *scan = strchr( buf, '$' ) + 1;
-  len = (strlen( buf ) - strlen( scan )) -1;
- 
-  if( scan[0] == '{' || scan[0] == '(' )
+  if(scan[0] == '{' || scan[0] == '(')
     scan++;
  
   ptr = (char*)scan;
   
-  while( *scan && *scan != '}' && *scan != ')' && *scan != '/' ){
+  while(*scan && *scan != '}' && *scan != ')' && *scan != '/'){
     scan++;
     x++;
   }
  
-  if( scan[0] == '}' || scan[0] == ')' )
+  if(scan[0] == '}' || scan[0] == ')')
     scan++;
  
-  string = substring( ptr, 0, x );
-  if( hash_lookup( hash_table, string ) == 0 ){
-    if( getenv( string ) != NULL )
+  string = substring(ptr, 0, x);
+  if(hash_lookup( hash_table, string) == 0){
+    if(getenv(string) != NULL)
       ENV = 1;
     else{
       string = '\0'; /* user botched his config file */
     }
   }
  
-  memset( final, 0, sizeof( final ));
-  strncpy( final, buf, len );
-  if( string != NULL )
-    strcat( final, ENV==0?hash_get(hash_table, string):getenv(string));
-  strcat( final, scan );
-  memset( result, 0, sizeof(result));
-  strncpy( result, final, strlen( final ));
+  memset(final, 0, sizeof final);
+  strncpy( final, buf, len);
+  if(string != NULL)
+    strcat(final, ENV==0?hash_get(hash_table, string):getenv(string));
+  strcat(final, scan );
+  memset(result, 0, BUFSIZE * sizeof(char));
+  strncpy(result, final, strlen(final));
   
   xfree(string);
   return result;
